@@ -16,7 +16,7 @@ import binwalk.core.statuserver
 import binwalk.core.common
 import binwalk.core.settings
 import binwalk.core.plugin
-from binwalk.core.compat import *
+from binwalk.core.compat import bytes2str
 from binwalk.core.exceptions import *
 
 
@@ -144,7 +144,7 @@ class Result(object):
         self.plot = True
         self.name = None
 
-        for (k, v) in iterator(kwargs):
+        for (k, v) in kwargs.items():
             setattr(self, k, v)
 
 
@@ -415,7 +415,7 @@ class Module(object):
 
             # Values in self.target_file_list are either already open files (BlockFile instances), or paths
             # to files that need to be opened for scanning.
-            if isinstance(next_target_file, str):
+            if isinstance(next_target_file, str) or isinstance(next_target_file, unicode):
                 fp = self.config.open_file(next_target_file)
             else:
                 fp = next_target_file
@@ -474,7 +474,6 @@ class Module(object):
         # as enabled
         if not self.enabled:
             self.enabled = True
-
         self.validate(r)
         self._plugins_result(r)
 
@@ -616,7 +615,7 @@ class Status(object):
         self.clear()
 
     def clear(self):
-        for (k, v) in iterator(self.kwargs):
+        for (k, v) in self.kwargs.items():
             setattr(self, k, v)
 
 
@@ -657,7 +656,7 @@ class Modules(object):
 
     def _set_arguments(self, argv=None, kargv=None):
         if kargv:
-            for (k, v) in iterator(kargv):
+            for (k, v) in kargv.items():
                     k = self._parse_api_opt(k)
                     if v is not True and v is not False and v is not None:
                         if not isinstance(v, list):
@@ -705,14 +704,27 @@ class Modules(object):
                 modules[module] = module.PRIORITY
 
         # user-defined modules
-        import imp
+        import importlib.util
+        import importlib.machinery
+
+        def load_source(modname, filename):
+            loader = importlib.machinery.SourceFileLoader(modname, filename)
+            spec = importlib.util.spec_from_file_location(modname, filename, loader=loader)
+            module = importlib.util.module_from_spec(spec)
+            # The module is always executed and not cached in sys.modules.
+            # Uncomment the following line to cache the module.
+            # sys.modules[module.__name__] = module
+            loader.exec_module(module)
+            return module
+
         user_modules = binwalk.core.settings.Settings().user.modules
+
         for file_name in os.listdir(user_modules):
             if not file_name.endswith('.py'):
                 continue
             module_name = file_name[:-3]
             try:
-                user_module = imp.load_source(module_name, os.path.join(user_modules, file_name))
+                user_module = load_source(module_name, os.path.join(user_modules, file_name))
             except KeyboardInterrupt as e:
                 raise e
             except Exception as e:
@@ -733,8 +745,8 @@ class Modules(object):
         modules = {}
         help_string = "\n"
         help_string += "Binwalk v%s\n" % binwalk.__version__
-        help_string += "Craig Heffner, ReFirmLabs\n"
-        help_string += "https://github.com/ReFirmLabs/binwalk\n"
+        help_string += "Original author: Craig Heffner, ReFirmLabs\n"
+        help_string += "https://github.com/OSPG/binwalk\n"
         help_string += "\n"
         help_string += "Usage: binwalk [OPTIONS] [FILE1] [FILE2] [FILE3] ...\n"
 
@@ -765,6 +777,8 @@ class Modules(object):
                     fmt = "    %%s %%s%%-%ds%%s\n" % (25 - len(long_opt))
                     help_string += fmt % (short_opt, long_opt, optargs, module_option.description)
 
+        help_string += "\n[NOTICE] Binwalk v2.x will reach EOL in 12/12/2025. Please migrate to binwalk v3.x"
+
         return help_string + "\n"
 
     def execute(self, *args, **kwargs):
@@ -785,7 +799,7 @@ class Modules(object):
 
         # Add all loaded modules that marked themselves as enabled to the
         # run_modules list
-        for (module, obj) in iterator(self.executed_modules):
+        for (module, obj) in self.executed_modules.items():
             # Report the results if the module is enabled and if it is a
             # primary module or if it reported any results/errors
             if obj.enabled and (obj.PRIMARY or obj.results or obj.errors):
@@ -923,20 +937,20 @@ class Modules(object):
 
             if module_option.type == binwalk.core.common.BlockFile:
 
-                for k in get_keys(module_option.kwargs):
+                for k in list(module_option.kwargs.keys()):
                     kwargs[k] = []
                     for unk in unknown:
                         kwargs[k].append(unk)
 
-            elif has_key(args, module_option.long) and args[module_option.long] not in [None, False]:
+            elif module_option.long in args and args[module_option.long] not in [None, False]:
 
                 # Loop through all the kwargs for this command line option
-                for (name, default_value) in iterator(module_option.kwargs):
+                for (name, default_value) in module_option.kwargs.items():
 
                     # If this kwarg has not been previously processed, or if its priority is equal to or
                     # greater than the previously processed kwarg's priority,
                     # then let's process it.
-                    if not has_key(last_priority, name) or last_priority[name] <= module_option.priority:
+                    if not name in last_priority or last_priority[name] <= module_option.priority:
 
                         # Track the priority for future iterations that may
                         # process the same kwarg name
@@ -963,14 +977,14 @@ class Modules(object):
         '''
         if hasattr(obj, "KWARGS"):
             for module_argument in obj.KWARGS:
-                if has_key(kwargs, module_argument.name):
+                if module_argument.name in kwargs:
                     arg_value = kwargs[module_argument.name]
                 else:
                     arg_value = copy(module_argument.default)
 
                 setattr(obj, module_argument.name, arg_value)
 
-            for (k, v) in iterator(kwargs):
+            for (k, v) in kwargs.items():
                 if not hasattr(obj, k):
                     setattr(obj, k, v)
         else:
