@@ -1,7 +1,6 @@
 
 import os
 import binwalk
-from nose.tools import eq_, ok_
 
 def test_lzma():
     '''
@@ -19,13 +18,13 @@ def test_lzma():
                                quiet=True)
 
     # Test number of modules used
-    eq_(len(scan_result), 1)
+    assert len(scan_result) == 1
 
     # There should be only one result
-    eq_(len(scan_result[0].results), 1)
+    assert len(scan_result[0].results) == 1
 
     # That result should be at offset 0
-    eq_(scan_result[0].results[0].offset, 0)
+    assert scan_result[0].results[0].offset == 0
 
     # That result should be an LZMA file
-    ok_(scan_result[0].results[0].description == expected_result)
+    assert scan_result[0].results[0].description == expected_result
